/*
 *  A pushbutton with a pulldown resistor connected to digital pin 2
 *  on the Arduino board takes a picture from the computer's inbuilt
 *  camera whenever the button is pushed. The image is saved in the sketch
 *  folder (sketch > show sketch folder).
 *
 *  This example only works when a camera is connected to your commputer.
 *
 *  This example uses the Stadard Firmata installed on the Arduino board
 *  Tested with Processing 2.0b8
 *
 *   copyleft, 2013: Fabian Winkler
 */

import processing.video.*;
import cc.arduino.*;
import processing.serial.*; 

Capture cam;
Arduino arduino; 
PImage img;
int inputPin = 2;
int val;
int old_val;

void setup() {
  
  println(Arduino.list());    
  arduino = new Arduino(this, Arduino.list()[0], 57600);  
  arduino.pinMode(inputPin, Arduino.INPUT);
  
  size(640, 480);

  String[] cameras = Capture.list();
  
  if (cameras.length == 0) {
    println("There are no cameras available for capture.");
    exit();
  } else {
    println("Available cameras:");
    for (int i = 0; i < cameras.length; i++) {
      println(cameras[i]);
    }
    
    // The camera can be initialized directly using an 
    // element from the array returned by list():
    cam = new Capture(this, cameras[0]);
    cam.start();     
  }   
  
  // Images must be in the "data" directory to load correctly
  img = loadImage("moustache.png");
  
}

void draw() {
 
  if (cam.available() == true) {
    cam.read();
  }
  val = arduino.digitalRead(inputPin);

  image(cam, 0, 0);
  image(img, 0, 0);
  // The following does the same, and is faster when just drawing the image
  // without any additional resizing, transformations, or tint.
  //set(0, 0, cam);
  
  // take a picture when button is pressed:
  if (val == 1 && val != old_val) {
   String saveAs = "myPhoto" + millis() + ".png";
   save(saveAs);
   //println("smile!");
  } 
  
   old_val = val; 
}
