/*
 *  A pushbutton with a pulldown resistor connected to digital pin 2
 *  on the Arduino board allows the user to play a sound file. The file
 *  plays as long as the button is pushed and resumes playback where it 
 *  was paused the next time the button is pushed. The sound is looping.
 *
 *  This example uses the Stadard Firmata installed on the Arduino board
 *  and the Minim sound library, see: http://code.compartmental.net/tools/minim/quickstart/
 *  Tested with Processing 2.0b8
 *
 *   copyleft, 2013: Fabian Winkler
 */


import cc.arduino.*; 
import processing.serial.*; 
import ddf.minim.*; 
 
Minim minim; 
AudioPlayer mySound; 
Arduino arduino; 

int inputPin = 2;
int val = 0;
int oldval = 0; 
int playback_pos = 0; 
   
      
void setup()  
{  
   
  println(Arduino.list());     
  arduino = new Arduino(this, Arduino.list()[0], 57600);   
  arduino.pinMode(inputPin, Arduino.INPUT); 
   
  size(400, 400); 
  noStroke(); 
  
  minim = new Minim(this); 
  mySound = minim.loadFile("expressway.aiff"); 
  // make sure you put the file “expressway.aiff” in your “data” folder  
  fill(255, 127, 0); 
} 
   
void draw()   
{   
  val = arduino.digitalRead(inputPin); 
 
  background(204); 
  
  if (val != oldval && val == 1) { 
  // the line above makes sure we only trigger the sound once 
  // when the pushbutton is pressed & held down 
     fill(0, 170, 0); // fill green 
     mySound.play(); 
   } 
    
  if (val != oldval && val == 0) { 
  // the line above makes sure we only pause the sound once 
  // when the pushbutton is released 
     fill(255, 127, 0); // fill orange  
     mySound.pause(); 
   } 
   
  rect(50, 50, 300, 300); 
  oldval = val; 
  //println(playback_pos);
  
  //makes sure to play sound as a loop:
  if (mySound.position()>=mySound.length()-50){
    mySound.rewind();
  }
} 
  
  
void stop() 
{ 
  // always close Minim audio classes when you are done with them 
 mySound.close(); 
 minim.stop(); 
 super.stop(); 
}
