/**
  * This example uses Minim’s AudioSnippet class – it ensures an immediate playback of the files but has the disadvantage that you can only work with shorter sound files since all files are loaded into RAM – see: http://code.compartmental.net/tools/minim/manual-audiosnippet/
  *
  * Use Minim’s AudioPlayer class (http://code.compartmental.net/tools/minim/manual-audioplayer/) if you have longer files. We use the AudioPlayer class in example 5 of the Processing/Arduino workshop.
  *
  * How it works:
  * I am using 4 sound files that I recorded with the contact microphone. Each time the button connected to the Arduino board is pushed one of the four sounds is triggered randomly. The sound plays until it reaches the end of the sound file, then the Processing sketch waits for the next push of the button.
  * Tested with Processing 2.0b8
  * copyleft, 2011: Fabian Winkler
  */

import cc.arduino.*;
import processing.serial.*;
import ddf.minim.*;
 
Arduino arduino;  
Minim minim;
int inputPin = 2;
int numberOfSounds = 4;  // change this number to reflect how many sounds you are using
                         // In this example I am using 4 differnt sounds
AudioSnippet[] sound = new AudioSnippet[numberOfSounds];
int soundNumber = 0;     // takes care of which sound should be playing

int val = 0;
int oldval = 0;

 
void setup()
{
  size(400, 400);
 
  minim = new Minim(this);
  // load files into the AudioSnippet array
  // the files must be in this sketch's data folder
  // short .mp3 files work well
  sound[0] = minim.loadSnippet("radiator.mp3");
  sound[1] = minim.loadSnippet("creaking_stairs.mp3"); 
  sound[2] = minim.loadSnippet("water_drops.mp3");
  sound[3] = minim.loadSnippet("snow.mp3");
  
  noStroke();
  fill(255, 127, 0); // fill orange
  
  println(Arduino.list());    
  arduino = new Arduino(this, Arduino.list()[0], 57600);  
  arduino.pinMode(inputPin, Arduino.INPUT);
  
  background(127);
}
 
void draw()
{
  
  val = arduino.digitalRead(inputPin); 
  
  // make sure to rewind the sound file once it is done playing or once it is replaced by another one
  if (sound[soundNumber].position() >= sound[soundNumber].length()) {
   sound[soundNumber].rewind();
  }
  
  // take care of sound playback when button is pushed
  if (val != oldval && val == 1) {
      // first stop and rewind currently playing sound:
      sound[soundNumber].pause();
      sound[soundNumber].rewind();
      
      // then generate a new random number to decide which sound to play next:
      soundNumber = (int)random(numberOfSounds);
  
      // play the new sound:
      sound[soundNumber].play();
  
      fill(0, 170, 0); // fill green
  }
  
   // reset color of sqaure to orange when the push button is released
  if (val != oldval && val == 0) {
    fill(255, 127, 0); // fill orange 
  }
  
  rect(50, 50, 300, 300);
  oldval = val;
}

 
void stop()
{
  // always close Minim audio classes
  for (int i=0; i<numberOfSounds; i++) {
    sound[i].close();
  }
  
  // always stop Minim before exiting
  minim.stop();
 
  super.stop();
}
