/**
  * This processing sketch randomly plays back video excerpts from D.W. Griffith’s film “Abraham Lincoln” - http://www.archive.org/details/abraham_lincoln. It creates non-linear and possibly new interpretations of Lincoln’s life through recombinant strategies.
  *
  * How it works:
  * Pressing a pushbutton connected to the Arduino board randomly plays one of six videos. The video playback stops at the end of the video and the Processing sketch waits for the next button push to play another randomly chosen video.
  * Check out Processing's video library at: http://processing.org/reference/libraries/video
  * for more things you can do with video in Processing.
  *
  * This example uses the Stadard Firmata installed on the Arduino board
  * Tested with Processing 2.0b8
  *
  * copyleft, 2011: Fabian Winkler
  *
 */
 
import cc.arduino.*;
import processing.serial.*;
import processing.video.*;

Arduino arduino;

// change the following code line to put in your own videos,
// don't forget to put them into the sketches' "data" folder
String[] vids = new String[]{"lincoln_00.mov", "lincoln_01.mov", "lincoln_02.mov", "lincoln_03.mov", "lincoln_04.mov", "lincoln_05.mov"};
Movie[] myMovie = new Movie[vids.length];

int inputPin = 2;
int val = 0;
int oldval = 0;
boolean[] isPlaying = new boolean[vids.length];
int vidNum = 0;


void setup() {
  size(320, 240);
  frame.setResizable(true);
  background(0);
  println(Arduino.list());    
  arduino = new Arduino(this, Arduino.list()[0], 57600);  
  arduino.pinMode(inputPin, Arduino.INPUT);
  
  // put all movies in their own movie object:
  for (int i=0; i < vids.length; i++){
     myMovie[i] = new Movie(this, vids[i]); 
  }
  
  // always start out with video number 1, i.e array element 0: 
  myMovie[0].play();
  myMovie[1].pause();
  myMovie[2].pause();
  myMovie[3].pause();
  myMovie[4].pause();
  myMovie[5].pause();

}

void draw() {
val = arduino.digitalRead(inputPin);
  
  // make sure we only trigger the video switch once
  // when the pushbutton is pressed & held down
  if (val != oldval && val == 1) {

     //create random numbers from 0 to (the amount of videos imported) -1
     vidNum = (int)random(vids.length);
     // switch video to the number randomly generated
     switch (vidNum) {
       case 0:
         myMovie[0].jump(0);
         myMovie[0].play();
         myMovie[1].pause();
         myMovie[2].pause();
         myMovie[3].pause();
         myMovie[4].pause();
         myMovie[5].pause();
      break; 
      case 1:
         myMovie[0].pause();
         myMovie[1].jump(0);
         myMovie[1].play();
         myMovie[2].pause();
         myMovie[3].pause();
         myMovie[4].pause();
         myMovie[5].pause();
      break;
      case 2:
         myMovie[0].pause();
         myMovie[1].pause();
         myMovie[2].jump(0);
         myMovie[2].play();
         myMovie[3].pause();
         myMovie[4].pause();
         myMovie[5].pause();
      break;
      case 3:
         myMovie[0].pause();
         myMovie[1].pause();
         myMovie[2].pause();
         myMovie[3].jump(0);
         myMovie[3].play();
         myMovie[4].pause();
         myMovie[5].pause();
         //image(myMovie[3], 0, 0);
      break;
      case 4:
         myMovie[0].pause();
         myMovie[1].pause();
         myMovie[2].pause();
         myMovie[3].pause();
         myMovie[4].jump(0);
         myMovie[4].play();
         myMovie[5].pause();
      break;
      case 5:
         myMovie[0].pause();
         myMovie[1].pause();
         myMovie[2].pause();
         myMovie[3].pause();
         myMovie[4].pause();
         myMovie[5].jump(0);
         myMovie[5].play();
      break;
     }
  }
  
  image(myMovie[vidNum], 0, 0);
oldval=val;
}
  

 // Called every time a new frame is available to read
void movieEvent(Movie m) {
  m.read();
}








